@@ -23,11 +23,14 @@
 #ifndef GSHTERM_COMMAND_LINE_H
 #define GSHTERM_COMMAND_LINE_H
 
+#include "gshterm.h"
+
 gboolean
-gshterm_construct_command_from_args(int argc, char **argv, gchar **command);
+gshterm_construct_command_from_args(
+	struct GSHTerm *term, int argc, char **argv, gchar **command);
 
 char*
-gshterm_construct_command(int argc, char **argv);
+gshterm_construct_command(struct GSHTerm *term, int argc, char **argv);
 
 #endif /* GSHTERM_COMMAND_LINE_H */
 
