@@ -22,6 +22,8 @@
 
 #include "gshterm.h"
 
+extern char *gshterm_font;
+
 void
 gshterm_set_terminal_options(GtkWidget *terminal)
 {
@@ -29,18 +31,30 @@ gshterm_set_terminal_options(GtkWidget *terminal)
 	vte_terminal_set_allow_bold(VTE_TERMINAL(terminal), TRUE);
 	vte_terminal_set_backspace_binding(VTE_TERMINAL(terminal),
 		VTE_ERASE_ASCII_BACKSPACE);
+	if(!gshterm_font)
+		asprintf(&gshterm_font, "Mono 18");
+	vte_terminal_set_font_from_string(VTE_TERMINAL(terminal), gshterm_font);
+	free(gshterm_font);
+	vte_terminal_set_background_transparent(
+		VTE_TERMINAL(terminal), TRUE);
 }
 
-GtkWidget *
-gshterm_setup_terminal()
+GtkWidget*
+gshterm_setup_terminal(struct GSHTerm *term)
 {
 	GtkWidget *terminal;
 
+#ifdef DEBUG
+	assert(term);
+	assert(term->gsh);
+	assert(term->gsh->window);
+#endif /* DEBUG */
+
 	terminal=vte_terminal_new();
-	gtk_container_add(GTK_CONTAINER(gsh_window), terminal);
+	gtk_container_add(GTK_CONTAINER(term->gsh->window), terminal);
 	gshterm_set_terminal_options(terminal);
 	gtk_widget_show(terminal);
-
+	term->widget=terminal;
 	return(terminal);
 }
 
