@@ -26,6 +26,14 @@
 #include <vte/vte.h>
 #include <unistd.h>
 
+struct GSHTerm
+{
+	struct GSH *gsh;
+	gchar *script;
+	gchar *font;
+	GtkWidget *widget;
+};
+
 #include "command_line.h"
 #include "script.h"
 
