@@ -23,8 +23,10 @@
 #ifndef GSH_ADD_OPTIONS_H
 #define GSH_ADD_OPTIONS_H
 
+#include "gtkshell.h"
+
 void
-gsh_handle_add_arguments(int argc, char **argv, unsigned int *counter);
+gsh_handle_add_arguments(struct GSH *gsh, int argc, char **argv, int *counter);
 
 #endif
 
