@@ -22,23 +22,20 @@
 
 #include "gtkshell.h"
 
-extern unsigned int gsh_rows;
-extern unsigned int gsh_row;
-
 void
-gsh_parse_arguments(int argc, char **argv)
+gsh_parse_arguments(struct GSH *gsh, int argc, char **argv)
 {
- unsigned int counter;
+ int counter;
 
- for (counter = 1; counter < (unsigned int)argc; counter++)
+ for (counter = 1; counter < argc; counter++)
  {
   if (argv[counter][0] == '-')
   {
-   gsh_handle_switch_arguments(argc, argv, &counter);
+   gsh_handle_switch_arguments(gsh, argc, argv, &counter);
   }
   else
   {
-   gsh_command_button(argv[counter]);
+   gsh_command_button(gsh, argv[counter]);
   }
  }
 }
