@@ -19,13 +19,16 @@
   along with AntiRight; if not, write to the Free Software
   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 */
+
 #ifndef GSH_ARGUMENTS_H
 #define GSH_ARGUMENTS_H
 
-void
-gsh_parse_arguments(int argc, char **argv);
+#include "gtkshell.h"
 
 void
-gsh_check_row();
+gsh_parse_arguments(struct GSH *gsh, int argc, char **argv);
+
+void
+gsh_check_row(struct GSH *gsh);
 
 #endif
