@@ -25,24 +25,37 @@
 GtkWidget *gsh_button;
 
 void
-gsh_command_button(char *command)
+gsh_command_button(struct GSH *gsh, char *command)
 {
- char           *label_text;
- label_text = antiright_beautified_label(command);
- gsh_button = gtk_button_new_with_label(label_text);
- free(label_text);
- g_signal_connect(G_OBJECT(gsh_button), "clicked",
-		  G_CALLBACK(system_cb), command);
- gsh_manage(gsh_button);
+	char *label_text;
+	struct GSH_CBData *cb;
+
+	/* Allocate and initialize elements.  */
+	cb=(struct GSH_CBData *)xmalloc(sizeof(struct GSH_CBData));
+	cb->gsh=gsh;
+
+	asprintf((char **)&cb->data, "%s", command);
+	label_text = antiright_beautified_label(command);
+	gsh->button = gtk_button_new_with_label(label_text);
+	free(label_text);
+
+	g_signal_connect(G_OBJECT(gsh->button), "clicked",
+		G_CALLBACK(system_cb), cb);
+
+	gsh_manage(gsh, gsh->button);
+
+#ifdef DEBUG
+	g_print("row: %d out of %d rows\n", gsh->rows.row, gsh->rows.rows);
+#endif /* DEBUG */
 }
 
 void
-gsh_image_button(char *command, char *filename)
+gsh_image_button(struct GSH *gsh, char *command, char *filename)
 {
 	GtkWidget *image;
 	image=gtk_image_new_from_file(filename);
-	gsh_command_button(command);
-	gtk_button_set_image(GTK_BUTTON(gsh_button), image);
-	gtk_button_set_relief(GTK_BUTTON(gsh_button), GTK_RELIEF_NONE);
+	gsh_command_button(gsh, command);
+	gtk_button_set_image(GTK_BUTTON(gsh->button), image);
+	gtk_button_set_relief(GTK_BUTTON(gsh->button), GTK_RELIEF_NONE);
 }
 
