@@ -23,9 +23,9 @@
 #define GSH_BUTTON_H
 
 void
-gsh_command_button(char *command);
+gsh_command_button(struct GSH *gsh, char *command);
 
 void
-gsh_image_button(char *command, char *filename);
+gsh_image_button(struct GSH *gsh, char *command, char *filename);
 
 #endif
