@@ -22,33 +22,33 @@
 
 #include "gtkshell.h"
 
-gboolean gsh_button_exits=FALSE;
-
 void
-gsh_test_exit()
+gsh_test_exit(struct GSH *gsh)
 {
-	if (gsh_button_exits)
+	if (gsh->flags.button_exits)
 		exit(0);
 }
 
 void
 system_cb(GtkWidget * widget, gpointer data)
 {
+    struct GSH_CBData *cb;
+    cb=(struct GSH_CBData *)data;
 	UNUSED(widget);
 
-	antiright_system(data);
-	gsh_test_exit();
+	antiright_system(cb->data);
+	gsh_test_exit(cb->gsh);
 }
 
 void
 entry_cb(GtkWidget * widget, gpointer data)
 {
-	gchar          *command;
 	const gchar    *input;
+    struct GSH_CBData *cb;
+
+    cb=(struct GSH_CBData *)data;
 
 	input = gtk_entry_get_text(GTK_ENTRY(widget));
-	asprintf(&command, "%s %s", (char *) data, (char *) input);
-	system_cb(NULL, command);
-	free(command);
+	sysprintf("%s %s", (char *) cb->data, (char *) input);
 }
 
