@@ -22,6 +22,12 @@
 #ifndef GSH_CALLBACKS_H
 #define GSH_CALLBACKS_H
 
+struct GSH_CBData
+{
+    struct GSH *gsh;
+    gpointer data;
+};
+
 void
 system_cb(GtkWidget * widget, gpointer data);
 
