@@ -24,10 +24,10 @@
 #define GSH_CONTAINERS_H
 
 void
-gsh_setup_scrolled_window();
+gsh_setup_scrolled_window(struct GSH *gsh);
 
 void
-gsh_setup_containers();
+gsh_setup_containers(struct GSH *gsh);
 
 #endif /* GSH_CONTAINERS_H */
 
