@@ -24,8 +24,8 @@
 #define GSH_DIALOG_OPTIONS
 
 void
-gsh_handle_dialog_arguments(int argc, char **argv,
-	unsigned int *counter);
+gsh_handle_dialog_arguments(struct GSH *gsh, int argc, char **argv,
+	int *counter);
 
 
 #endif
