@@ -23,14 +23,14 @@
 #ifndef GSH_FILE_DIALOG
 #define GSH_FILE_DIALOG
 void   
-gsh_file_dialog(GtkFileChooserAction action);
+gsh_file_dialog(struct GSH *gsh, GtkFileChooserAction action);
 void
-gsh_file_open_dialog();
+gsh_file_open_dialog(struct GSH *gsh);
 void
-gsh_file_save_dialog();
+gsh_file_save_dialog(struct GSH *gsh);
 void
-gsh_folder_open_dialog();
+gsh_folder_open_dialog(struct GSH *gsh);
 void
-gsh_folder_create_dialog();
+gsh_folder_create_dialog(struct GSH *gsh);
 #endif
 
