@@ -22,32 +22,6 @@
 
 #include "gtkshell.h"
 
-extern char *gsh_geometry;
-
-void
-gsh_set_geometry()
-{
-	assert(gsh_geometry);
-	gtk_window_parse_geometry(GTK_WINDOW(gsh_window), 
-		gsh_geometry);
-}
-void
-gsh_check_and_set_geometry()
-{
-	if(gsh_geometry!=NULL)
-	{	
-		gsh_set_geometry();
-		free(gsh_geometry);
-	}
-	else
-	{
-		asprintf(&gsh_geometry, "500x300");
-		gsh_set_geometry();
-		free(gsh_geometry);
-	}
-
-}
-
 GtkWidget *
 gsh_create_main_window()
 {
@@ -62,11 +36,52 @@ gsh_create_main_window()
 
 	return(window);		
 }
-
 void
+gsh_GSH_Flags(struct GSH_Flags *flags)
+{
+	flags->dont_scroll=FALSE;
+	flags->button_exits=FALSE;
+	flags->updating=FALSE;
+}
+void
+gsh_GSH_Rows(struct GSH_Rows *rows)
+{
+	/* rows->row is initialized by gsh_manage.  */
+	rows->rows=8;
+}
+void
+gsh_GSH(struct GSH *gsh)
+{
+	gsh->geometry=NULL;
+	gsh->update_period=1000;
+	gsh_GSH_Flags(&gsh->flags);
+	gsh_GSH_Rows(&gsh->rows);
+}
+struct GSH *
+gsh_new_GSH()
+{
+	struct GSH *gsh;
+
+	gsh=(struct GSH *)xmalloc(sizeof(struct GSH));
+	gsh_GSH(gsh);
+
+	return gsh;
+}
+struct GSH *
 gsh_init(int *argc, char ***argv)
+{
+	struct GSH *gsh;
+	
+	gsh=gsh_new_GSH();
+	gsh_stack_init(gsh, argc, argv);
+
+	return gsh;
+}
+void
+gsh_stack_init(struct GSH *gsh, int *argc, char ***argv)
 {
 	gtk_init(argc, argv);
-	gsh_window=gsh_create_main_window();
+	gsh_GSH(gsh);
+	gsh->window=gsh_create_main_window();
 }
 
