@@ -23,12 +23,12 @@
 #include "gtkshell.h"
 
 void
-gsh_add_label(char *text)
+gsh_add_label(struct GSH *gsh, char *text)
 {
  GtkWidget      *label;
 
  label = gtk_label_new(text);
- gsh_manage(label);
+ gsh_manage(gsh, label);
 }
 
 void
@@ -41,3 +41,4 @@ gsh_set_label(GtkWidget *label, char *text)
 	gtk_label_set_markup(GTK_LABEL(label), markup);
 	g_free(markup);
 }
+
