@@ -24,7 +24,7 @@
 #define GSH_LABEL_H
 
 void
-gsh_add_label(char *text);
+gsh_add_label(struct GSH *gsh, char *text);
 
 void
 gsh_set_label(GtkWidget *label, char *text);
