@@ -22,27 +22,29 @@
 
 #include "gtkshell.h"
 
-extern gboolean gsh_dont_scroll;
-
 int
 main(int argc, char **argv)
 {
- 	gtk_init(&argc, &argv);
+	struct GSH *gsh;
 
-	gsh_window=gsh_create_main_window();
- 	
-	if(((argc > 1) && (strlen(argv[1]) == 3)) 
-		&& !strncmp(argv[1], "-os", 3))
-	{
-		gsh_dont_scroll=TRUE;
-	}
-	gsh_setup_containers();
- 	gsh_parse_arguments(argc, argv);
+ 	gsh=gsh_init(&argc, &argv);
 
-	gsh_check_and_set_geometry();
+	gsh->flags.dont_scroll= 
+		(((argc > 1) 
+		&& (strlen(argv[1]) == 3)) 
+		&& !strncmp(argv[1], "-os", 3)) 
+		? TRUE : FALSE;
+
+	gsh_setup_containers(gsh);
+ 	gsh_parse_arguments(gsh, argc, argv);
+
+	gsh_check_and_set_geometry(gsh);
+
+ 	gtk_widget_show(gsh->window);
+
+	/* Free object references and initialization variables */
+	g_free(gsh); 
 
- 	gtk_widget_show(gsh_window);
-	
  	gtk_main();
 
 	return (0);
