@@ -22,35 +22,30 @@
 
 #include "gtkshell.h"
 
-extern unsigned int gsh_rows;
-extern gboolean gsh_button_exits;
-extern unsigned int gsh_update_period;
-char *gsh_geometry;
-
 void
-gsh_handle_option_arguments(int argc, char **argv, unsigned int *counter)
+gsh_handle_option_arguments(struct GSH *gsh, int argc, char **argv, int *counter)
 {
 	switch(argv[(*counter)][2])
 	{
 		case 'e':
-			gsh_button_exits=TRUE;
+			gsh->flags.button_exits=TRUE;
 			break;
 		case 'g':
 			gsh_count(argc, counter);
-			asprintf(&gsh_geometry, "%s", argv[(*counter)]);
+			asprintf(&gsh->geometry, "%s", argv[(*counter)]);
 			break;
 		case 'n':
-			gtk_window_set_decorated(GTK_WINDOW(gsh_window), FALSE);                                             
-                	gtk_window_set_skip_taskbar_hint(
-				GTK_WINDOW(gsh_window), TRUE);                                      
-                	break;
+			gtk_window_set_decorated(GTK_WINDOW(gsh->window), FALSE);                                             
+            gtk_window_set_skip_taskbar_hint(
+			    GTK_WINDOW(gsh->window), TRUE);                                      
+            break;
 		case 'r':
 			gsh_count(argc, counter);
-			gsh_rows=(unsigned int)atoi(argv[(*counter)]);
+			gsh->rows.rows=(unsigned int)atoi(argv[(*counter)]);
 			break;
 		case 'u':
 			gsh_count(argc, counter);
-			gsh_update_period=atoi(argv[*counter]);
+			gsh->update_period=atoi(argv[*counter]);
 			break;
 	}
 }
