@@ -24,6 +24,7 @@
 #define GSH_OPTION_OPTIONS_H
 
 void
-gsh_handle_option_arguments(int argc, char **argv, unsigned int *counter);
+gsh_handle_option_arguments(
+    struct GSH *gsh, int argc, char **argv, int *counter);
 
 #endif
