@@ -22,10 +22,12 @@
 #ifndef GSH_OPTIONS_H
 #define GSH_OPTIONS_H
 
+#include "gtkshell.h"
+
 void
 gsh_count(int argc, int *counter);
 
 void
-gsh_handle_switch_arguments(int argc, char **argv, unsigned int *counter);
+gsh_handle_switch_arguments(struct GSH *gsh, int argc, char **argv, int *counter);
 
 #endif
