@@ -22,43 +22,46 @@
 
 #include "gtkshell.h"
 
-unsigned int gsh_rows=8;
-unsigned int gsh_row=1;
-
 void
-gsh_manage(GtkWidget *widget)
+gsh_manage(struct GSH *gsh, GtkWidget *widget)
 {
- gsh_check_row();
- gtk_container_add(GTK_CONTAINER(gsh_vbox), widget);
+ gsh_check_row(gsh);
+ gtk_container_add(GTK_CONTAINER(gsh->rows.v), widget);
  gtk_widget_show(widget);
- gsh_row++;
+ gsh->rows.row++;
+
 #ifdef DEBUG
- printf("gsh_row: %d, gsh_rows: %d\n", gsh_row, gsh_rows);
+ g_print("gsh_row: %d, gsh_rows: %d\n", gsh->rows.row, gsh->rows.rows);
 #endif
+
 }
 
 
 void
-gsh_new_row()
+gsh_new_row(struct GSH *gsh)
 {
- gsh_vbox = gtk_vbox_new(FALSE, 2);
- gtk_container_add(GTK_CONTAINER(gsh_hbox), gsh_vbox);
- gtk_widget_show(gsh_vbox);
- gsh_row = 1;
+ gsh->rows.v = gtk_vbox_new(FALSE, 2);
+ gtk_container_add(GTK_CONTAINER(gsh->rows.h), gsh->rows.v);
+ gtk_widget_show(gsh->rows.v);
+ gsh->rows.row = 0;
 }
 
 void
-gsh_check_row()
+gsh_check_row(struct GSH *gsh)
 {
+
 #ifdef DEBUG
- printf("==> gsh_row: %d, gsh_rows: %d\n", gsh_row, gsh_rows);
+ printf("==> gsh_row: %d, gsh_rows: %d\n", gsh->rows.row, gsh->rows.rows);
 #endif
 
- if(gsh_row > gsh_rows)
+ if(gsh->rows.row == gsh->rows.rows)
  {
-  gsh_new_row();
+
+#ifdef DEBUG 
+	g_print("new row");
+#endif
+
+  gsh_new_row(gsh);
  }
 }
 
-
-
