@@ -23,12 +23,12 @@
 #define GSH_ROW_H
 
 void
-gsh_manage(GtkWidget *widget);
+gsh_manage(struct GSH *gsh, GtkWidget *widget);
 
 void
-gsh_new_row();
+gsh_new_row(struct GSH *gsh);
 
 void
-gsh_check_row();
+gsh_check_row(struct GSH *gsh);
 
 #endif /* GSH_ROW_H */
