@@ -23,32 +23,36 @@
 #include "gtkshell.h"
 
 GtkWidget*
-gsh_setup_command_entry(char *command)
+gsh_setup_command_entry(struct GSH *gsh, char *command)
 {
  GtkWidget      *entry;
+	struct GSH_CBData *cb;
 
+	cb=(struct GSH_CBData *)xmalloc(sizeof(struct GSH_CBData));
+	cb->gsh=gsh;
+	asprintf((char **)&cb->data, "%s", command);
  entry = gtk_entry_new();
  g_signal_connect(G_OBJECT(entry), "activate", G_CALLBACK(entry_cb),
-		  (gpointer) command);
- gsh_manage(entry);
+		  (gpointer) cb);
+ gsh_manage(gsh, entry);
  return(entry);
 }
 
 void
-gsh_setup_prompt_command_entry(char *command)
+gsh_setup_prompt_command_entry(struct GSH *gsh, char *command)
 {
 	GtkWidget *entry;
-	entry=gsh_setup_command_entry(command);
+	entry=gsh_setup_command_entry(gsh, command);
 	g_signal_connect(G_OBJECT(entry), "activate", 
 		G_CALLBACK(gtk_main_quit), NULL);
 }
 
 void
-gsh_text_area()
+gsh_text_area(struct GSH *gsh)
 {
 	GtkWidget *text;
 	
 	text=gtk_text_view_new();
-	gsh_manage(text);
+	gsh_manage(gsh, text);
 }
 
