@@ -24,10 +24,10 @@
 #define GSH_TEXT_H
 
 GtkWidget*
-gsh_setup_command_entry(char *command);
+gsh_setup_command_entry(struct GSH *gsh, char *command);
 
 void
-gsh_setup_prompt_command_entry(char *command);
+gsh_setup_prompt_command_entry(struct GSH *gsh, char *command);
 
 void
 gsh_text_area();
