@@ -23,26 +23,19 @@
 #ifndef GSH_UPDATED_H
 #define GSH_UPDATED_H
 
-struct gsh_updated_struct
+typedef struct
 {
-	void *next;
 	void (*function)(char *, void *);
 	char *command;
 	void *widget;
-};
+} gsh_updater_data;
 
 void
-gsh_add_to_updates(struct gsh_updated_struct *update);
-
-void
-gsh_add_update(void (*function)(char *, void *),
+gsh_add_updater(void (*function)(char *, void *),
         char *command, void *widget);
 
-void    
+void
 gsh_start_updates();
 
-gint
-gsh_perform_updates(gpointer data);
-
 #endif
 
