@@ -27,7 +27,7 @@ void
 gsh_update_label(char *command, void *widget);
 
 void
-gsh_add_updated_label(char *command);
+gsh_add_updated_label(struct GSH *gsh, char *command);
 
 #endif
 
