@@ -24,6 +24,7 @@
 #define GSH_UPDATED_OPTIONS_H
 
 void
-gsh_handle_updated_arguments(int argc, char **argv, unsigned int *counter);
+gsh_handle_updated_arguments(struct GSH *gsh, int argc, 
+	char **argv, int *counter);
 
 #endif
