@@ -32,11 +32,11 @@ gsh_update_progress(char *command, void *widget)
 	free(results);
 }
 void
-gsh_add_updated_progress(char *command)
+gsh_add_updated_progress(struct GSH *gsh, char *command)
 {
 	GtkWidget *widget;
 	widget=gtk_progress_bar_new();
-	gsh_manage(widget);
+	gsh_manage(gsh, widget);
 	gsh_add_updater(&gsh_update_progress, command, (void*)widget);
 }
 
