@@ -27,7 +27,7 @@ void
 gsh_update_progress(char *command, void *widget);
 
 void
-gsh_add_updated_progress(char *command);
+gsh_add_updated_progress(struct GSH *gsh, char *command);
 
 #endif
 
