@@ -1,6 +1,6 @@
 /*
   AntiRight
-  (c) 2002-2005 Jeffrey Bedard
+  (c) 2002-2007 Jeffrey Bedard
   antiright@gmail.com
 
   This file is part of AntiRight.
@@ -22,7 +22,15 @@
 
 #ifndef LIBAR_SYSTEM_H
 #define LIBAR_SYSTEM_H
+
 int
 antiright_system(char *field_string);
-#endif
+
+int
+sysprintf(char *format, ...);
+
+int
+vsysprintf(char *format, va_list list);
+
+#endif /* LIBAR_SYSTEM_H */
 
