@@ -22,7 +22,7 @@
 
 #include "library.h"
 
-void *
+gpointer
 xmalloc(size_t size)
 {
   gpointer pointer;
@@ -32,4 +32,16 @@ xmalloc(size_t size)
   return(pointer);
 }
 
+void
+rand_seed()
+{
+	srand((unsigned int)time(NULL));
+}
+
+int
+rand_ranged(int start, int finish)
+{
+	return rand()%(finish-start)+start;
+}
+
 
