@@ -22,10 +22,17 @@
 
 #ifndef LIBAR_UTIL_H
 #define LIBAR_UTIL_H
-void *
+
+gpointer
 xmalloc(size_t size);
 
 #define UNUSED(arg) { arg = arg; }
 
+void
+rand_seed();
+
+int
+rand_ranged(int start, int finish);
+
 #endif
 
